@@ -4,15 +4,16 @@ import sys
 import traceback
 from contextlib import contextmanager
 from enum import Enum
+from threading import Thread
 from pathlib import Path
 from types import MethodType
 from typing import Optional, List, Any, Tuple, Callable, Union, Dict, Sequence, NewType
 
-import PyQt5.QtCore as qc
-import PyQt5.QtWidgets as qw
+import qtpy.QtCore as qc
+import qtpy.QtWidgets as qw
 import attr
-from PyQt5.QtCore import QModelIndex, Qt, QVariant
-from PyQt5.QtGui import QFont, QCloseEvent, QDesktopServices
+from qtpy.QtCore import QModelIndex, Qt, QVariant
+from qtpy.QtGui import QFont, QCloseEvent, QDesktopServices
 
 import corrscope
 import corrscope.settings.global_prefs as gp
@@ -36,6 +37,7 @@ from corrscope.gui.model_bind import (
     BoundComboBox,
 )
 from corrscope.gui.util import color2hex, Locked, find_ranges, TracebackDialog
+from corrscope.gui.version_common import QT6
 from corrscope.gui.view_mainwindow import MainWindow as Ui_MainWindow
 from corrscope.gui.widgets import ChannelTableView, ShortcutButton
 from corrscope.layout import Orientation, StereoOrientation
@@ -52,6 +54,7 @@ from corrscope.util import obj_name, iround, coalesce
 from corrscope.wave import Flatten
 
 FILTER_WAV_FILES = ["WAV files (*.wav)"]
+FILTER_IMAGES = ["Images files (*.png *.jpg *.jpeg *.gif)", "All files (*)"]
 
 APP_NAME = f"{corrscope.app_name} {corrscope.__version__}"
 APP_DIR = Path(__file__).parent
@@ -82,7 +85,8 @@ def gui_main(cfg_or_path: Union[Config, Path]):
 
     # qw.QApplication.setStyle('fusion')
     QApp = qw.QApplication
-    QApp.setAttribute(qc.Qt.AA_EnableHighDpiScaling)
+    if not QT6:
+        QApp.setAttribute(qc.Qt.AA_EnableHighDpiScaling)
 
     app = qw.QApplication(sys.argv)
 
@@ -109,8 +113,8 @@ def gui_main(cfg_or_path: Union[Config, Path]):
     # ffmpeg receives SIGPIPE and terminates by itself (according to strace).
     corr_thread = window.corr_thread
     if corr_thread is not None:
-        corr_thread.abort_terminate()
-        corr_thread.wait()
+        corr_thread.job.abort_terminate()
+        corr_thread.join()
 
     sys.exit(ret)
 
@@ -191,6 +195,7 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
 
         # Bind UI buttons, etc. Functions block main thread, avoiding race conditions.
         self.master_audio_browse.clicked.connect(self.on_master_audio_browse)
+        self.bg_image_browse.clicked.connect(self.on_bg_image_browse)
 
         self.channelUp.add_shortcut(self.channelsGroup, "ctrl+shift+up")
         self.channelDown.add_shortcut(self.channelsGroup, "ctrl+shift+down")
@@ -445,6 +450,15 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
             self.model[master_audio] = name
             self.model.update_all_bound(master_audio)
 
+    def on_bg_image_browse(self):
+        name = get_open_file_name(
+            self, "Open background image file", self.pref.file_dir_ref, FILTER_IMAGES
+        )
+        if name:
+            bg_image = "render__bg_image"
+            self.model[bg_image] = name
+            self.model.update_all_bound(bg_image)
+
     def on_separate_render_dir_toggled(self, checked: bool):
         self.pref.separate_render_dir = checked
         if checked:
@@ -567,23 +581,23 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
         if dlg:
             # t.abort -> Locked.set() is thread-safe (hopefully).
             # It can be called from main thread (not just within CorrThread).
-            dlg.canceled.connect(t.abort, Qt.DirectConnection)
-            t.arg = attr.evolve(
+            dlg.canceled.connect(t.job.abort, Qt.DirectConnection)
+            t.job.arg = attr.evolve(
                 arg,
                 on_begin=run_on_ui_thread(dlg.on_begin, (float, float)),
                 progress=run_on_ui_thread(dlg.setValue, (int,)),
                 on_end=run_on_ui_thread(dlg.reset, ()),  # TODO dlg.close
             )
 
-        t.finished.connect(self.on_play_thread_finished)
-        t.error.connect(self.on_play_thread_error)
-        t.ffmpeg_missing.connect(self.on_play_thread_ffmpeg_missing)
+        t.job.finished.connect(self.on_play_thread_finished)
+        t.job.error.connect(self.on_play_thread_error)
+        t.job.ffmpeg_missing.connect(self.on_play_thread_ffmpeg_missing)
         t.start()
 
     @safe_property
     def preview_or_render(self) -> str:
         if self.corr_thread is not None:
-            return self.tr(self.corr_thread.mode.value)
+            return self.tr(self.corr_thread.job.mode.value)
         return "neither preview nor render"
 
     def _get_args(self, outputs: List[IOutputConfig]):
@@ -663,12 +677,12 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
         return self.model.cfg
 
     # Misc.
-    @qc.pyqtSlot()
+    @qc.Slot()
     def on_action_website(self):
         website_url = r"https://github.com/corrscope/corrscope/"
         QDesktopServices.openUrl(qc.QUrl(website_url))
 
-    @qc.pyqtSlot()
+    @qc.Slot()
     def on_action_help(self):
         help_url = r"https://corrscope.github.io/corrscope/"
         QDesktopServices.openUrl(qc.QUrl(help_url))
@@ -697,10 +711,10 @@ class PreviewOrRender(Enum):
     render = qc.QT_TRANSLATE_NOOP("MainWindow", "render")
 
 
-class CorrThread(qc.QThread):
+class CorrJob(qc.QObject):
     is_aborted: Locked[bool]
 
-    @qc.pyqtSlot()
+    @qc.Slot()
     def abort(self):
         self.is_aborted.set(True)
 
@@ -711,11 +725,12 @@ class CorrThread(qc.QThread):
             for output in self.corr.outputs:
                 output.terminate(from_same_thread=False)
 
-    error = qc.pyqtSignal(str)
-    ffmpeg_missing = qc.pyqtSignal()
+    finished = qc.Signal()
+    error = qc.Signal(str)
+    ffmpeg_missing = qc.Signal()
 
     def __init__(self, cfg: Config, arg: Arguments, mode: PreviewOrRender):
-        qc.QThread.__init__(self)
+        qc.QObject.__init__(self)
         self.is_aborted = Locked(False)
 
         self.cfg = cfg
@@ -745,6 +760,21 @@ class CorrThread(qc.QThread):
             arg.on_end()
 
 
+class CorrThread(Thread):
+    job: CorrJob
+
+    def __init__(self, cfg: Config, arg: Arguments, mode: PreviewOrRender):
+        Thread.__init__(self)
+        self.job = CorrJob(cfg, arg, mode)
+
+    def run(self):
+        """Callback invoked on new thread."""
+        try:
+            self.job.run()
+        finally:
+            self.job.finished.emit()
+
+
 class CorrProgressDialog(qw.QProgressDialog):
     def __init__(self, parent: Optional[qw.QWidget], title: str):
         super().__init__(parent)
@@ -761,7 +791,7 @@ class CorrProgressDialog(qw.QProgressDialog):
         # Close after CorrScope finishes.
         self.setAutoClose(True)
 
-    @qc.pyqtSlot(float, float)
+    @qc.Slot(float, float)
     def on_begin(self, begin_time, end_time):
         self.setRange(iround(begin_time), iround(end_time))
         # self.setValue is called by CorrScope, on the first frame.
@@ -997,6 +1027,8 @@ class ConfigModel(PresentationModel):
 @attr.dataclass
 class Column:
     key: str
+
+    # fn(str) -> T. If ValueError is thrown, replaced by `default`.
     cls: Union[type, Callable[[str], Any]]
 
     # `default` is written into config,
@@ -1007,6 +1039,7 @@ class Column:
         return self.key.replace("__", "\n").replace("_", " ").title()
 
     display_name: str = attr.Factory(_display_name, takes_self=True)
+    always_show: bool = False
 
 
 def plus_minus_one(value: str) -> int:
@@ -1019,6 +1052,26 @@ def plus_minus_one(value: str) -> int:
 nope = qc.QVariant()
 
 
+def parse_bool_maybe(s: str) -> Optional[bool]:
+    """Does not throw. But could legally throw ValueError."""
+
+    if not s:
+        return None
+
+    # len(s) >= 1
+    try:
+        return bool(int(s))
+    except ValueError:
+        pass
+
+    s = s.lower()
+    if s[0] in ["t", "y"]:
+        return True
+    if s[0] in ["f", "n"]:
+        return False
+    return None
+
+
 class ChannelModel(qc.QAbstractTableModel):
     """Design based off
     https://doc.qt.io/qt-5/model-view-programming.html#a-read-only-example-model and
@@ -1057,16 +1110,18 @@ class ChannelModel(qc.QAbstractTableModel):
         Column("label", str, "", "Label"),
         Column("amplification", float, None, "Amplification\n(override)"),
         Column("line_color", str, None, "Line Color"),
+        Column("color_by_pitch", parse_bool_maybe, None, "Color Lines\nBy Pitch"),
         Column("render_stereo", str, None, "Render Stereo\nDownmix"),
-        Column("trigger_width", int, None, "Trigger Width ×"),
-        Column("render_width", int, None, "Render Width ×"),
-        Column("trigger__sign_strength", float, None),
-        Column("trigger__buffer_strength", float, None),
-        Column("trigger__responsiveness", float, None, "Buffer\nResponsiveness"),
+        Column("trigger_width", int, 1, "Trigger Width ×", always_show=True),
+        Column("render_width", int, 1, "Render Width ×", always_show=True),
+        Column("trigger__mean_responsiveness", float, None, "DC Removal\nRate"),
+        Column("trigger__sign_strength", float, None, "Sign\nAmplification"),
         Column("trigger__edge_direction", plus_minus_one, None),
         Column("trigger__edge_strength", float, None),
-        Column("trigger__slope_strength", float, None),
         Column("trigger__slope_width", float, None),
+        Column("trigger__buffer_strength", float, None),
+        Column("trigger__responsiveness", float, None, "Buffer\nResponsiveness"),
+        Column("trigger__reset_below", float, None, "Reset Below\nMatch"),
     ]
 
     idx_of_key = {}
@@ -1116,7 +1171,7 @@ class ChannelModel(qc.QAbstractTableModel):
             else:
                 value = getattr(self.channels[row], key)
 
-            if value == data.default:
+            if not data.always_show and value == data.default:
                 return ""
             if key == "wav_path" and role == Qt.DisplayRole:
                 if Path(value).parent != Path():
