@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 from contextlib import contextmanager
 
-from PyQt5.QtCore import *
-from PyQt5.QtWidgets import *
+from qtpy.QtCore import *
+from qtpy.QtWidgets import *
 
 from corrscope.gui.view_stack import (
     LayoutStack,
@@ -160,13 +160,36 @@ class MainWindow(QWidget):
                 with add_row(s, "", BoundColorWidget) as self.render__bg_color:
                     pass
 
+                with add_row(s, tr("Background image"), QHBoxLayout):
+                    with append_widget(s, BoundLineEdit) as self.render__bg_image:
+                        pass
+                    with append_widget(s, QPushButton) as self.bg_image_browse:
+                        self.bg_image_browse.setText(tr("&Browse..."))
+
                 with add_row(s, "", BoundColorWidget) as self.render__init_line_color:
                     pass
 
+                with add_row(
+                    s, BoundCheckBox, Both
+                ) as self.render__global_color_by_pitch:
+                    self.render__global_color_by_pitch.setText(
+                        tr("Color Lines By Pitch")
+                    )
+
                 with add_row(s, "", BoundDoubleSpinBox) as self.render__line_width:
                     self.render__line_width.setMinimum(0.5)
                     self.render__line_width.setSingleStep(0.5)
 
+                with add_row(
+                    s, tr("Outline Color"), BoundColorWidget
+                ) as self.render__global_line_outline_color:
+                    pass
+
+                with add_row(
+                    s, tr("Outline Width"), BoundDoubleSpinBox
+                ) as self.render__line_outline_width:
+                    self.render__line_outline_width.setSingleStep(0.5)
+
                 with add_row(s, "", OptionalColorWidget) as self.render__grid_color:
                     pass
 
@@ -274,7 +297,18 @@ class MainWindow(QWidget):
             ):
                 with add_row(
                     s,
-                    tr("Sign Triggering\n(for triangle waves)"),
+                    tr("DC Removal Rate"),
+                    BoundDoubleSpinBox,
+                    name="trigger__mean_responsiveness",
+                    minimum=0,
+                    maximum=1,
+                    singleStep=0.25,
+                ):
+                    pass
+
+                with add_row(
+                    s,
+                    tr("Sign Amplification\n(for triangle waves)"),
                     BoundDoubleSpinBox,
                     name="trigger__sign_strength",
                     minimum=0,
@@ -282,28 +316,6 @@ class MainWindow(QWidget):
                 ):
                     pass
 
-            with append_widget(
-                s, QGroupBox, title=tr("Wave History Alignment"), layout=QFormLayout
-            ):
-                with add_row(
-                    s,
-                    tr("Buffer Strength"),
-                    BoundDoubleSpinBox,
-                    name="trigger__buffer_strength",
-                ):
-                    pass
-                with add_row(
-                    s,
-                    tr("Buffer Responsiveness"),
-                    BoundDoubleSpinBox,
-                    name="trigger__responsiveness",
-                    maximum=1.0,
-                    singleStep=0.1,
-                ):
-                    pass
-                with add_row(s, BoundCheckBox, Both) as (self.trigger__pitch_tracking):
-                    assert isinstance(self.trigger__pitch_tracking, QWidget)
-
             with append_widget(
                 s, QGroupBox, title=tr("Edge Triggering"), layout=QFormLayout
             ):
@@ -321,14 +333,6 @@ class MainWindow(QWidget):
                     name="trigger__edge_strength",
                 ):
                     s.widget.setMinimum(0.0)
-                with add_row(
-                    s,
-                    tr("Slope Strength\n(for PSG/C64/FM)"),
-                    BoundDoubleSpinBox,
-                    name="trigger__slope_strength",
-                ):
-                    s.widget.setSingleStep(10)
-                    s.widget.setMaximum(200)
                 with add_row(
                     s,
                     tr("Slope Width"),
@@ -336,9 +340,40 @@ class MainWindow(QWidget):
                     name="trigger__slope_width",
                 ):
                     s.widget.setMinimum(0)
-                    s.widget.setMaximum(0.5)
+                    s.widget.setMaximum(2)
                     s.widget.setSingleStep(0.02)
 
+            with append_widget(
+                s, QGroupBox, title=tr("Wave History Alignment"), layout=QFormLayout
+            ):
+                with add_row(
+                    s,
+                    tr("Buffer Strength"),
+                    BoundDoubleSpinBox,
+                    name="trigger__buffer_strength",
+                ):
+                    pass
+                with add_row(
+                    s,
+                    tr("Buffer Responsiveness"),
+                    BoundDoubleSpinBox,
+                    name="trigger__responsiveness",
+                    maximum=1.0,
+                    singleStep=0.1,
+                ):
+                    pass
+                with add_row(
+                    s,
+                    tr("Reset Below Match"),
+                    BoundDoubleSpinBox,
+                    name="trigger__reset_below",
+                    maximum=1.0,
+                    singleStep=0.1,
+                ):
+                    pass
+                with add_row(s, BoundCheckBox, Both) as (self.trigger__pitch_tracking):
+                    assert isinstance(self.trigger__pitch_tracking, QWidget)
+
             with append_widget(
                 s, QGroupBox, title=tr("Post Triggering"), layout=QFormLayout
             ):
@@ -442,10 +477,10 @@ class MainWindow(QWidget):
         self.actionPreview = QAction(MainWindow)
         self.actionRender = QAction(MainWindow)
 
+        self.actionHelp = create_element(QAction, MainWindow, text=tr("&Help Tutorial"))
         self.actionWebsite = create_element(
-            QAction, MainWindow, text=tr("corrscope Website")
+            QAction, MainWindow, text=tr("&Project Homepage")
         )
-        self.actionHelp = create_element(QAction, MainWindow, text=tr("Help"))
 
         self.action_separate_render_dir = create_element(
             QAction, MainWindow, text=tr("&Separate Render Folder"), checkable=True
@@ -477,8 +512,8 @@ class MainWindow(QWidget):
 
             with append_menu(s, title=tr("&Help")) as self.menuHelp:
                 w = self.menuHelp
-                w.addAction(self.actionWebsite)
                 w.addAction(self.actionHelp)
+                w.addAction(self.actionWebsite)
 
         # Setup toolbar
         with add_toolbar(s, Qt.TopToolBarArea) as self.toolBar:
