@@ -22,6 +22,8 @@ class IOutputConfig(DumpableAttrs):
     cls: "ClassVar[Type[Output]]"
 
     def __call__(self, corr_cfg: "Config") -> "Output":
+        """Must be called in the .yaml file's directory.
+        This is used to properly resolve corr_cfg.master_audio."""
         return self.cls(corr_cfg, cfg=self)
 
 
@@ -49,7 +51,7 @@ class Output(ABC):
 
     @abstractmethod
     def write_frame(self, frame: ByteBuffer) -> Optional[_Stop]:
-        """ Output a Numpy ndarray. """
+        """Output a Numpy ndarray."""
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         pass
@@ -62,7 +64,7 @@ class Output(ABC):
 
 
 def register_output(
-    config_t: Type[IOutputConfig]
+    config_t: Type[IOutputConfig],
 ) -> Callable[[Type[Output]], Type[Output]]:
     def inner(output_t: Type[Output]):
         config_t.cls = output_t
@@ -130,7 +132,7 @@ def ffmpeg_input_audio(audio_path: str) -> List[str]:
 
 class PipeOutput(Output):
     def open(self, *pipeline: subprocess.Popen) -> None:
-        """ Called by __init__ with a Popen pipeline to ffmpeg/ffplay. """
+        """Called by __init__ with a Popen pipeline to ffmpeg/ffplay."""
         if len(pipeline) == 0:
             raise TypeError("must provide at least one Popen argument to popens")
 
@@ -217,10 +219,34 @@ class PipeOutput(Output):
 
 class FFmpegOutputConfig(IOutputConfig):
     # path=None writes to stdout.
+    #
+    # This parameter is not loaded from disk, but set when the user picks a render path
+    # on the GUI or calls the CLI with `--render out.mp4`.
+    #
+    # It must be an absolute path. How is this ensured?
+    #
+    # - Paths supplied from the GUI are always absolute.
+    # - Paths supplied from the CLI must be resolved before storing in
+    #   FFmpegOutputConfig.
+    #
+    # Why are relative paths not allowed? Currently, to resolve `corr_cfg.master_audio`
+    # relative to the config file, we change directories to the config dir, then call
+    # `abspath(corr_cfg.master_audio)`. As a result, if we called `corr dir/cfg.yaml -r
+    # out.mp4` and corrscope didn't resolve `out.mp4` before passing into
+    # FFmpegOutputConfig, it would mistakenly write to `dir/out.mp4`.
+    #
+    # In the future, relative paths could be allowed by not switching directories to the
+    # config dir, and finding another way to resolve `corr_cfg.master_audio` based on
+    # the config dir.
     path: Optional[str]
     args: str = ""
 
-    video_template: str = "-c:v libx264 -crf 18 -preset superfast -pix_fmt yuv420p -movflags faststart"
+    video_template: str = (
+        "-c:v libx264 -crf 18 -preset superfast "
+        "-pix_fmt yuv420p -vf scale=out_color_matrix=bt709 "
+        "-color_range 1 -colorspace bt709 -color_trc bt709 -color_primaries bt709 "
+        "-movflags faststart"
+    )
     audio_template: str = "-c:a aac -b:a 384k"
 
 
