@@ -8,6 +8,7 @@ Backend implementation does not know about RendererFrontend.
 """
 
 import enum
+import math
 import os
 from abc import ABC, abstractmethod
 from collections import defaultdict
@@ -27,10 +28,12 @@ from typing import (
     MutableSequence,
 )
 
+# DO NOT IMPORT MATPLOTLIB UNTIL WE DELETE mpl_config_dir!
 import attr
 import numpy as np
-from matplotlib.cm import get_cmap
 
+import corrscope.generate
+from corrscope.channel import ChannelConfig, Channel
 from corrscope.config import DumpableAttrs, with_units, TypedEnumDump
 from corrscope.layout import (
     RendererLayout,
@@ -62,8 +65,12 @@ if mpl_config_dir in os.environ:
     del os.environ[mpl_config_dir]
 
 # matplotlib.use() only affects pyplot. We don't use pyplot.
-import matplotlib
+
+import matplotlib as mpl
+import matplotlib.cm
 import matplotlib.colors
+import matplotlib.image
+import matplotlib.patheffects
 from matplotlib.backends.backend_agg import FigureCanvasAgg
 from matplotlib.figure import Figure
 
@@ -75,7 +82,6 @@ if TYPE_CHECKING:
     from matplotlib.lines import Line2D
     from matplotlib.spines import Spine
     from matplotlib.text import Text, Annotation
-    from corrscope.channel import ChannelConfig, Channel
 
 
 # Used by outputs.py.
@@ -147,6 +153,7 @@ class RendererConfig(
     width: int
     height: int
     line_width: float = with_units("px", default=1.5)
+    line_outline_width: float = with_units("px", default=0.0)
     grid_line_width: float = with_units("px", default=1.0)
 
     @property
@@ -158,7 +165,18 @@ class RendererConfig(
         return round(self.height / self.res_divisor)
 
     bg_color: str = "#000000"
+    bg_image: str = ""
     init_line_color: str = default_color()
+    global_line_outline_color: str = "#000000"
+
+    @property
+    def global_line_color(self) -> str:
+        return self.init_line_color
+
+    # Whether to color lines by the pitch of the current note.
+    global_color_by_pitch: bool = False
+    # 12 colors, representing how to color pitches C through B.
+    pitch_colors: List[str] = corrscope.generate.spectral_colors
 
     grid_color: Optional[str] = None
     stereo_grid_opacity: float = 0.25
@@ -177,7 +195,7 @@ class RendererConfig(
 
     @property
     def get_label_color(self):
-        return coalesce(self.label_color_override, self.init_line_color)
+        return coalesce(self.label_color_override, self.global_line_color)
 
     antialiasing: bool = True
 
@@ -192,6 +210,7 @@ class RendererConfig(
         # round(np.int32 / float) == np.float32, but we want int.
         assert isinstance(self.width, (int, float))
         assert isinstance(self.height, (int, float))
+        assert len(self.pitch_colors) == 12, len(self.pitch_colors)
 
     # Both before_* functions should be idempotent, AKA calling twice does no harm.
     def before_preview(self) -> None:
@@ -203,12 +222,62 @@ class RendererConfig(
         self.res_divisor = 1
 
 
+def gen_circular_cmap(colors: List[str]):
+    colors = list(colors)
+
+    # `colors` has 12 distinct entries.
+    # LinearSegmentedColormap(colors) takes a real number `x` between 0 and 1,
+    # and maps x=0 to colors[0] and x=1 to colors[-1].
+    # pitch_cmap should be periodic, so `colors[0]` should appear at both x=0 and x=1.
+    colors.append(colors[0])
+
+    cmap = matplotlib.colors.LinearSegmentedColormap.from_list(
+        "12-tone spectrum", colors, N=256, gamma=1.0
+    )
+    return cmap
+
+
+def freq_to_color(cmap, freq: Optional[float], fallback_color: str) -> str:
+    if not freq:
+        return fallback_color
+
+    key_number = 12 * math.log2(freq / 440) + 69
+
+    color = cmap(math.fmod(key_number, 12) / 12)
+    return color
+
+
 @attr.dataclass
 class LineParam:
     color: str
+    color_by_pitch: bool
 
 
-UpdateLines = Callable[[List[np.ndarray]], Any]
+@attr.dataclass
+class RenderInput:
+    # Should Renderer store a Wave and take an int?
+    # Or take an array on each frame?
+    data: np.ndarray
+    freq_estimate: Optional[float]
+
+    @staticmethod
+    def stub_new(data: np.ndarray) -> "RenderInput":
+        """
+        Stable function to construct a RenderInput given only a data array.
+        Used mainly for tests.
+        """
+        return RenderInput(data, None)
+
+    @staticmethod
+    def wrap_datas(datas: List[np.ndarray]) -> List["RenderInput"]:
+        """
+        Stable function to construct a list of RenderInput given only datas.
+        Used mainly for tests.
+        """
+        return [RenderInput.stub_new(data) for data in datas]
+
+
+UpdateLines = Callable[[List[RenderInput]], Any]
 UpdateOneLine = Callable[[np.ndarray], Any]
 
 
@@ -271,6 +340,9 @@ class _RendererBackend(ABC):
         self.w = cfg.divided_width
         self.h = cfg.divided_height
 
+        # Maps a continuous variable from 0 to 1 (representing one octave) to a color.
+        self.pitch_cmap = gen_circular_cmap(cfg.pitch_colors)
+
         self.nplots = len(dummy_datas)
 
         if self.nplots > 0:
@@ -278,19 +350,20 @@ class _RendererBackend(ABC):
         self.wave_nsamps = [data.shape[0] for data in dummy_datas]
         self.wave_nchans = [data.shape[1] for data in dummy_datas]
 
-        # Load line colors.
-        if channel_cfgs is not None:
-            if len(channel_cfgs) != self.nplots:
-                raise ValueError(
-                    f"cannot assign {len(channel_cfgs)} colors to {self.nplots} plots"
-                )
-            line_colors = [cfg.line_color for cfg in channel_cfgs]
-        else:
-            line_colors = [None] * self.nplots
+        if channel_cfgs is None:
+            channel_cfgs = [ChannelConfig("") for _ in range(self.nplots)]
+
+        if len(channel_cfgs) != self.nplots:
+            raise ValueError(
+                f"cannot assign {len(channel_cfgs)} colors to {self.nplots} plots"
+            )
 
         self._line_params = [
-            LineParam(color=coalesce(color, cfg.init_line_color))
-            for color in line_colors
+            LineParam(
+                color=coalesce(ccfg.line_color, cfg.global_line_color),
+                color_by_pitch=coalesce(ccfg.color_by_pitch, cfg.global_color_by_pitch),
+            )
+            for ccfg in channel_cfgs
         ]
 
         # Load channel strides.
@@ -438,6 +511,12 @@ class AbstractMatplotlibRenderer(_RendererBackend, ABC):
         # Setup background
         self._fig.set_facecolor(cfg.bg_color)
 
+        if cfg.bg_image:
+            img = mpl.image.imread(cfg.bg_image)
+
+            ax = self._fig.add_axes([0, 0, 1, 1])
+            ax.imshow(img)
+
         # Create Axes (using self.lcfg, wave_nchans)
         # _axes2d[wave][chan] = Axes
         self._axes2d = self.layout.arrange(self._axes_factory)
@@ -461,7 +540,7 @@ class AbstractMatplotlibRenderer(_RendererBackend, ABC):
             # List of colors at
             # https://matplotlib.org/gallery/color/colormap_reference.html
             # Discussion at https://github.com/matplotlib/matplotlib/issues/10840
-            cmap: ListedColormap = get_cmap("Accent")
+            cmap: ListedColormap = matplotlib.cm.get_cmap("Accent")
             colors = cmap.colors
             axes.set_prop_cycle(color=colors)
 
@@ -592,9 +671,22 @@ class AbstractMatplotlibRenderer(_RendererBackend, ABC):
             for chan_idx, chan_zeros in enumerate(wave_zeros.T):
                 ax = wave_axes[chan_idx]
                 line_color = self._line_params[wave_idx].color
+
                 chan_line: Line2D = ax.plot(
                     xs, chan_zeros, color=line_color, linewidth=line_width
                 )[0]
+
+                if cfg.line_outline_width > 0:
+                    chan_line.set_path_effects(
+                        [
+                            mpl.patheffects.Stroke(
+                                linewidth=cfg.line_width + 2 * cfg.line_outline_width,
+                                foreground=cfg.global_line_outline_color,
+                            ),
+                            mpl.patheffects.Normal(),
+                        ]
+                    )
+
                 wave_lines.append(chan_line)
 
             lines2d.append(wave_lines)
@@ -602,17 +694,16 @@ class AbstractMatplotlibRenderer(_RendererBackend, ABC):
 
         return lambda datas: self._update_lines_stereo(lines2d, datas)
 
-    @staticmethod
     def _update_lines_stereo(
-        lines2d: "List[List[Line2D]]", datas: List[np.ndarray]
+        self, lines2d: "List[List[Line2D]]", inputs: List[RenderInput]
     ) -> None:
         """
         Preconditions:
         - lines2d[wave][chan] = Line2D
-        - datas[wave] = ndarray, [samp][chan] = FLOAT
+        - inputs[wave] = ndarray, [samp][chan] = f32
         """
         nplots = len(lines2d)
-        ndata = len(datas)
+        ndata = len(inputs)
         if nplots != ndata:
             raise ValueError(
                 f"incorrect data to plot: {nplots} plots but {ndata} dummy_datas"
@@ -620,13 +711,29 @@ class AbstractMatplotlibRenderer(_RendererBackend, ABC):
 
         # Draw waveform data
         # Foreach wave
-        for wave_idx, wave_data in enumerate(datas):
+        for wave_idx, input in enumerate(inputs):
+            wave_data = input.data
+            freq_estimate = input.freq_estimate
+
             wave_lines = lines2d[wave_idx]
 
+            color_by_pitch = self._line_params[wave_idx].color_by_pitch
+
+            # If we color notes by pitch, then on every frame,
+            # recompute the color based on current pitch.
+            # If no sound is detected, fall back to the default color.
+            # If we don't color notes by pitch,
+            # just keep the initial color and never overwrite it.
+            if color_by_pitch:
+                fallback_color = self._line_params[wave_idx].color
+                color = freq_to_color(self.pitch_cmap, freq_estimate, fallback_color)
+
             # Foreach chan
             for chan_idx, chan_data in enumerate(wave_data.T):
                 chan_line = wave_lines[chan_idx]
                 chan_line.set_ydata(chan_data)
+                if color_by_pitch:
+                    chan_line.set_color(color)
 
     def _add_xy_line_mono(
         self, wave_idx: int, xs: Sequence[float], ys: Sequence[float], stride: int
@@ -791,7 +898,7 @@ class RendererFrontend(_RendererBackend, ABC):
         self._update_main_lines = None
         self._custom_lines = {}  # type: Dict[Any, CustomLine]
         self._vlines = {}  # type: Dict[Any, CustomLine]
-        self._offsetable = defaultdict(list)
+        self._absolute = defaultdict(list)
 
     # Overrides implementations of _RendererBackend.
     def get_frame(self) -> ByteBuffer:
@@ -807,13 +914,20 @@ class RendererFrontend(_RendererBackend, ABC):
     # New methods.
     _update_main_lines: Optional[UpdateLines]
 
-    def update_main_lines(self, datas: List[np.ndarray]) -> None:
+    def update_main_lines(
+        self, inputs: List[RenderInput], trigger_samples: List[int]
+    ) -> None:
+        datas = [input.data for input in inputs]
+
         if self._update_main_lines is None:
             self._update_main_lines = self.add_lines_stereo(datas, self.render_strides)
 
-        self._update_main_lines(datas)
+        self._update_main_lines(inputs)
+        assert len(datas) == len(trigger_samples)
+        for i, (data, trigger) in enumerate(zip(datas, trigger_samples)):
+            self.move_viewport(i, trigger)  # - len(data) / 2
 
-    _offsetable: DefaultDict[int, MutableSequence[CustomLine]]
+    _absolute: DefaultDict[int, MutableSequence[CustomLine]]
 
     def update_custom_line(
         self,
@@ -821,8 +935,8 @@ class RendererFrontend(_RendererBackend, ABC):
         wave_idx: int,
         stride: int,
         data: np.ndarray,
-        *,
-        offset: bool = True,
+        xs: np.ndarray,
+        absolute: bool,
     ):
         data = data.copy()
         key = (name, wave_idx)
@@ -830,39 +944,43 @@ class RendererFrontend(_RendererBackend, ABC):
         if key not in self._custom_lines:
             line = self._add_line_mono(wave_idx, stride, data)
             self._custom_lines[key] = line
-            if offset:
-                self._offsetable[wave_idx].append(line)
+            if absolute:
+                self._absolute[wave_idx].append(line)
         else:
             line = self._custom_lines[key]
 
+        line.xdata = xs
+        line.set_xdata(xs)
         line.set_ydata(data)
 
     def update_vline(
-        self, name: str, wave_idx: int, stride: int, x: int, *, offset: bool = True
+        self, name: str, wave_idx: int, stride: int, x: int, *, absolute: bool = True
     ):
         key = (name, wave_idx)
         if key not in self._vlines:
             line = self._add_vline_mono(wave_idx, stride)
             self._vlines[key] = line
-            if offset:
-                self._offsetable[wave_idx].append(line)
+            if absolute:
+                self._absolute[wave_idx].append(line)
         else:
             line = self._vlines[key]
 
         line.xdata = [x * stride] * 2
         line.set_xdata(line.xdata)
 
-    def offset_viewport(self, wave_idx: int, viewport_offset: float):
-        line_offset = -viewport_offset
-
-        for line in self._offsetable[wave_idx]:
-            line.set_xdata(line.xdata + line_offset * line.stride)
+    def move_viewport(self, wave_idx: int, viewport_center: float):
+        for line in self._absolute[wave_idx]:
+            line.xdata -= viewport_center
+            line.set_xdata(line.xdata)
 
     def _add_line_mono(
-        self, wave_idx: int, stride: int, dummy_data: np.ndarray
+        self,
+        wave_idx: int,
+        stride: int,
+        dummy_data: np.ndarray,
     ) -> CustomLine:
+        xs = np.zeros_like(dummy_data)
         ys = np.zeros_like(dummy_data)
-        xs = calc_xs(len(ys), stride)
         return self._add_xy_line_mono(wave_idx, xs, ys, stride)
 
     def _add_vline_mono(self, wave_idx: int, stride: int) -> CustomLine:
